/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(NETSCAPE_PLUGIN_API)
#include "PluginControllerProxy.h"

#include "ArgumentCoders.h" // NOLINT
#include "DataReference.h" // NOLINT
#include "Decoder.h" // NOLINT
#include "HandleMessage.h" // NOLINT
#include "PluginControllerProxyMessages.h" // NOLINT
#include "ShareableBitmap.h" // NOLINT
#include "WebCoreArgumentCoders.h" // NOLINT
#include "WebKeyboardEvent.h" // NOLINT
#include "WebMouseEvent.h" // NOLINT
#include "WebWheelEvent.h" // NOLINT
#include <WebCore/AffineTransform.h> // NOLINT
#include <WebCore/IntRect.h> // NOLINT
#include <WebCore/IntSize.h> // NOLINT
#include <wtf/text/WTFString.h> // NOLINT

#if ENABLE(IPC_TESTING_API)
#include "JSIPCBinding.h"
#endif

namespace Messages {

namespace PluginControllerProxy {

} // namespace PluginControllerProxy

} // namespace Messages

namespace WebKit {

void PluginControllerProxy::didReceivePluginControllerProxyMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::PluginControllerProxy::GeometryDidChange::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::GeometryDidChange>(connection, decoder, this, &PluginControllerProxy::geometryDidChange);
    if (decoder.messageName() == Messages::PluginControllerProxy::VisibilityDidChange::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::VisibilityDidChange>(connection, decoder, this, &PluginControllerProxy::visibilityDidChange);
    if (decoder.messageName() == Messages::PluginControllerProxy::FrameDidFinishLoading::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::FrameDidFinishLoading>(connection, decoder, this, &PluginControllerProxy::frameDidFinishLoading);
    if (decoder.messageName() == Messages::PluginControllerProxy::FrameDidFail::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::FrameDidFail>(connection, decoder, this, &PluginControllerProxy::frameDidFail);
    if (decoder.messageName() == Messages::PluginControllerProxy::DidEvaluateJavaScript::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::DidEvaluateJavaScript>(connection, decoder, this, &PluginControllerProxy::didEvaluateJavaScript);
    if (decoder.messageName() == Messages::PluginControllerProxy::StreamWillSendRequest::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StreamWillSendRequest>(connection, decoder, this, &PluginControllerProxy::streamWillSendRequest);
    if (decoder.messageName() == Messages::PluginControllerProxy::StreamDidReceiveResponse::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StreamDidReceiveResponse>(connection, decoder, this, &PluginControllerProxy::streamDidReceiveResponse);
    if (decoder.messageName() == Messages::PluginControllerProxy::StreamDidReceiveData::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StreamDidReceiveData>(connection, decoder, this, &PluginControllerProxy::streamDidReceiveData);
    if (decoder.messageName() == Messages::PluginControllerProxy::StreamDidFinishLoading::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StreamDidFinishLoading>(connection, decoder, this, &PluginControllerProxy::streamDidFinishLoading);
    if (decoder.messageName() == Messages::PluginControllerProxy::StreamDidFail::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StreamDidFail>(connection, decoder, this, &PluginControllerProxy::streamDidFail);
    if (decoder.messageName() == Messages::PluginControllerProxy::ManualStreamDidReceiveResponse::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::ManualStreamDidReceiveResponse>(connection, decoder, this, &PluginControllerProxy::manualStreamDidReceiveResponse);
    if (decoder.messageName() == Messages::PluginControllerProxy::ManualStreamDidReceiveData::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::ManualStreamDidReceiveData>(connection, decoder, this, &PluginControllerProxy::manualStreamDidReceiveData);
    if (decoder.messageName() == Messages::PluginControllerProxy::ManualStreamDidFinishLoading::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::ManualStreamDidFinishLoading>(connection, decoder, this, &PluginControllerProxy::manualStreamDidFinishLoading);
    if (decoder.messageName() == Messages::PluginControllerProxy::ManualStreamDidFail::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::ManualStreamDidFail>(connection, decoder, this, &PluginControllerProxy::manualStreamDidFail);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleMouseEvent::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::HandleMouseEvent>(connection, decoder, this, &PluginControllerProxy::handleMouseEvent);
    if (decoder.messageName() == Messages::PluginControllerProxy::SetFocus::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::SetFocus>(connection, decoder, this, &PluginControllerProxy::setFocus);
    if (decoder.messageName() == Messages::PluginControllerProxy::DidUpdate::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::DidUpdate>(connection, decoder, this, &PluginControllerProxy::didUpdate);
    if (decoder.messageName() == Messages::PluginControllerProxy::WindowFocusChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::WindowFocusChanged>(connection, decoder, this, &PluginControllerProxy::windowFocusChanged);
    if (decoder.messageName() == Messages::PluginControllerProxy::WindowVisibilityChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::WindowVisibilityChanged>(connection, decoder, this, &PluginControllerProxy::windowVisibilityChanged);
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginControllerProxy::SendComplexTextInput::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::SendComplexTextInput>(connection, decoder, this, &PluginControllerProxy::sendComplexTextInput);
#endif
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginControllerProxy::WindowAndViewFramesChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::WindowAndViewFramesChanged>(connection, decoder, this, &PluginControllerProxy::windowAndViewFramesChanged);
#endif
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginControllerProxy::SetLayerHostingMode::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::SetLayerHostingMode>(connection, decoder, this, &PluginControllerProxy::setLayerHostingMode);
#endif
    if (decoder.messageName() == Messages::PluginControllerProxy::StorageBlockingStateChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::StorageBlockingStateChanged>(connection, decoder, this, &PluginControllerProxy::storageBlockingStateChanged);
    if (decoder.messageName() == Messages::PluginControllerProxy::PrivateBrowsingStateChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::PrivateBrowsingStateChanged>(connection, decoder, this, &PluginControllerProxy::privateBrowsingStateChanged);
    if (decoder.messageName() == Messages::PluginControllerProxy::MutedStateChanged::name())
        return IPC::handleMessage<Messages::PluginControllerProxy::MutedStateChanged>(connection, decoder, this, &PluginControllerProxy::mutedStateChanged);
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
#if ENABLE(IPC_TESTING_API)
    if (connection.ignoreInvalidMessageForTesting())
        return;
#endif // ENABLE(IPC_TESTING_API)
    ASSERT_NOT_REACHED_WITH_MESSAGE("Unhandled message %s to %" PRIu64, IPC::description(decoder.messageName()), decoder.destinationID());
}

bool PluginControllerProxy::didReceiveSyncPluginControllerProxyMessage(IPC::Connection& connection, IPC::Decoder& decoder, UniqueRef<IPC::Encoder>& replyEncoder)
{
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleWheelEvent::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandleWheelEvent>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handleWheelEvent);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleMouseEnterEvent::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandleMouseEnterEvent>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handleMouseEnterEvent);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleMouseLeaveEvent::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandleMouseLeaveEvent>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handleMouseLeaveEvent);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleKeyboardEvent::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandleKeyboardEvent>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handleKeyboardEvent);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandleEditingCommand::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandleEditingCommand>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handleEditingCommand);
    if (decoder.messageName() == Messages::PluginControllerProxy::IsEditingCommandEnabled::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::IsEditingCommandEnabled>(connection, decoder, replyEncoder, this, &PluginControllerProxy::isEditingCommandEnabled);
    if (decoder.messageName() == Messages::PluginControllerProxy::HandlesPageScaleFactor::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::HandlesPageScaleFactor>(connection, decoder, replyEncoder, this, &PluginControllerProxy::handlesPageScaleFactor);
    if (decoder.messageName() == Messages::PluginControllerProxy::RequiresUnifiedScaleFactor::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::RequiresUnifiedScaleFactor>(connection, decoder, replyEncoder, this, &PluginControllerProxy::requiresUnifiedScaleFactor);
    if (decoder.messageName() == Messages::PluginControllerProxy::PaintEntirePlugin::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::PaintEntirePlugin>(connection, decoder, replyEncoder, this, &PluginControllerProxy::paintEntirePlugin);
    if (decoder.messageName() == Messages::PluginControllerProxy::GetPluginScriptableNPObject::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::GetPluginScriptableNPObject>(connection, decoder, replyEncoder, this, &PluginControllerProxy::getPluginScriptableNPObject);
    if (decoder.messageName() == Messages::PluginControllerProxy::SupportsSnapshotting::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::SupportsSnapshotting>(connection, decoder, replyEncoder, this, &PluginControllerProxy::supportsSnapshotting);
    if (decoder.messageName() == Messages::PluginControllerProxy::Snapshot::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::Snapshot>(connection, decoder, replyEncoder, this, &PluginControllerProxy::snapshot);
    if (decoder.messageName() == Messages::PluginControllerProxy::GetFormValue::name())
        return IPC::handleMessageSynchronous<Messages::PluginControllerProxy::GetFormValue>(connection, decoder, replyEncoder, this, &PluginControllerProxy::getFormValue);
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    UNUSED_PARAM(replyEncoder);
#if ENABLE(IPC_TESTING_API)
    if (connection.ignoreInvalidMessageForTesting())
        return false;
#endif // ENABLE(IPC_TESTING_API)
    ASSERT_NOT_REACHED_WITH_MESSAGE("Unhandled synchronous message %s to %" PRIu64, description(decoder.messageName()), decoder.destinationID());
    return false;
}

} // namespace WebKit

#if ENABLE(IPC_TESTING_API)

namespace IPC {

template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_GeometryDidChange>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::GeometryDidChange::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_VisibilityDidChange>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::VisibilityDidChange::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_FrameDidFinishLoading>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::FrameDidFinishLoading::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_FrameDidFail>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::FrameDidFail::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_DidEvaluateJavaScript>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::DidEvaluateJavaScript::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StreamWillSendRequest>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StreamWillSendRequest::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StreamDidReceiveResponse>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StreamDidReceiveResponse::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StreamDidReceiveData>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StreamDidReceiveData::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StreamDidFinishLoading>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StreamDidFinishLoading::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StreamDidFail>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StreamDidFail::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_ManualStreamDidReceiveResponse>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::ManualStreamDidReceiveResponse::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_ManualStreamDidReceiveData>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::ManualStreamDidReceiveData::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_ManualStreamDidFinishLoading>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::ManualStreamDidFinishLoading::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_ManualStreamDidFail>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::ManualStreamDidFail::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleMouseEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleMouseEvent::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleWheelEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleWheelEvent::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandleWheelEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleWheelEvent::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleMouseEnterEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleMouseEnterEvent::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandleMouseEnterEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleMouseEnterEvent::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleMouseLeaveEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleMouseLeaveEvent::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandleMouseLeaveEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleMouseLeaveEvent::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleKeyboardEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleKeyboardEvent::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandleKeyboardEvent>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleKeyboardEvent::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandleEditingCommand>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleEditingCommand::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandleEditingCommand>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandleEditingCommand::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_IsEditingCommandEnabled>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::IsEditingCommandEnabled::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_IsEditingCommandEnabled>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::IsEditingCommandEnabled::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_HandlesPageScaleFactor>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandlesPageScaleFactor::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_HandlesPageScaleFactor>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::HandlesPageScaleFactor::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_RequiresUnifiedScaleFactor>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::RequiresUnifiedScaleFactor::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_RequiresUnifiedScaleFactor>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::RequiresUnifiedScaleFactor::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_SetFocus>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::SetFocus::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_DidUpdate>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::DidUpdate::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_PaintEntirePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::PaintEntirePlugin::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_PaintEntirePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::PaintEntirePlugin::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_GetPluginScriptableNPObject>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::GetPluginScriptableNPObject::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_GetPluginScriptableNPObject>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::GetPluginScriptableNPObject::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_WindowFocusChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::WindowFocusChanged::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_WindowVisibilityChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::WindowVisibilityChanged::Arguments>(globalObject, decoder);
}
#if PLATFORM(COCOA)
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_SendComplexTextInput>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::SendComplexTextInput::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_WindowAndViewFramesChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::WindowAndViewFramesChanged::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_SetLayerHostingMode>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::SetLayerHostingMode::Arguments>(globalObject, decoder);
}
#endif
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_SupportsSnapshotting>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::SupportsSnapshotting::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_SupportsSnapshotting>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::SupportsSnapshotting::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_Snapshot>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::Snapshot::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_Snapshot>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::Snapshot::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_StorageBlockingStateChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::StorageBlockingStateChanged::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_PrivateBrowsingStateChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::PrivateBrowsingStateChanged::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_GetFormValue>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::GetFormValue::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginControllerProxy_GetFormValue>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::GetFormValue::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginControllerProxy_MutedStateChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginControllerProxy::MutedStateChanged::Arguments>(globalObject, decoder);
}

}

#endif


#endif // ENABLE(NETSCAPE_PLUGIN_API)
