/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(NETSCAPE_PLUGIN_API)
#include "PluginProxy.h"

#include "ArgumentCoders.h" // NOLINT
#include "Decoder.h" // NOLINT
#include "HandleMessage.h" // NOLINT
#include "NPVariantData.h" // NOLINT
#include "PluginProxyMessages.h" // NOLINT
#include "WebCoreArgumentCoders.h" // NOLINT
#include <WebCore/HTTPHeaderMap.h> // NOLINT
#include <WebCore/IntRect.h> // NOLINT
#include <WebCore/ProtectionSpace.h> // NOLINT
#include <wtf/Vector.h> // NOLINT
#include <wtf/text/WTFString.h> // NOLINT

#if ENABLE(IPC_TESTING_API)
#include "JSIPCBinding.h"
#endif

namespace Messages {

namespace PluginProxy {

#if PLATFORM(X11)

#endif

} // namespace PluginProxy

} // namespace Messages

namespace WebKit {

void PluginProxy::didReceivePluginProxyMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    Ref protectedThis { *this };
    if (decoder.messageName() == Messages::PluginProxy::LoadURL::name())
        return IPC::handleMessage<Messages::PluginProxy::LoadURL>(connection, decoder, this, &PluginProxy::loadURL);
    if (decoder.messageName() == Messages::PluginProxy::Update::name())
        return IPC::handleMessage<Messages::PluginProxy::Update>(connection, decoder, this, &PluginProxy::update);
    if (decoder.messageName() == Messages::PluginProxy::SetCookiesForURL::name())
        return IPC::handleMessage<Messages::PluginProxy::SetCookiesForURL>(connection, decoder, this, &PluginProxy::setCookiesForURL);
    if (decoder.messageName() == Messages::PluginProxy::CancelStreamLoad::name())
        return IPC::handleMessage<Messages::PluginProxy::CancelStreamLoad>(connection, decoder, this, &PluginProxy::cancelStreamLoad);
    if (decoder.messageName() == Messages::PluginProxy::ContinueStreamLoad::name())
        return IPC::handleMessage<Messages::PluginProxy::ContinueStreamLoad>(connection, decoder, this, &PluginProxy::continueStreamLoad);
    if (decoder.messageName() == Messages::PluginProxy::CancelManualStreamLoad::name())
        return IPC::handleMessage<Messages::PluginProxy::CancelManualStreamLoad>(connection, decoder, this, &PluginProxy::cancelManualStreamLoad);
    if (decoder.messageName() == Messages::PluginProxy::SetStatusbarText::name())
        return IPC::handleMessage<Messages::PluginProxy::SetStatusbarText>(connection, decoder, this, &PluginProxy::setStatusbarText);
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginProxy::PluginFocusOrWindowFocusChanged::name())
        return IPC::handleMessage<Messages::PluginProxy::PluginFocusOrWindowFocusChanged>(connection, decoder, this, &PluginProxy::pluginFocusOrWindowFocusChanged);
#endif
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginProxy::SetComplexTextInputState::name())
        return IPC::handleMessage<Messages::PluginProxy::SetComplexTextInputState>(connection, decoder, this, &PluginProxy::setComplexTextInputState);
#endif
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::PluginProxy::SetLayerHostingContextID::name())
        return IPC::handleMessage<Messages::PluginProxy::SetLayerHostingContextID>(connection, decoder, this, &PluginProxy::setLayerHostingContextID);
#endif
#if PLATFORM(X11)
    if (decoder.messageName() == Messages::PluginProxy::WindowedPluginGeometryDidChange::name())
        return IPC::handleMessage<Messages::PluginProxy::WindowedPluginGeometryDidChange>(connection, decoder, this, &PluginProxy::windowedPluginGeometryDidChange);
#endif
#if PLATFORM(X11)
    if (decoder.messageName() == Messages::PluginProxy::WindowedPluginVisibilityDidChange::name())
        return IPC::handleMessage<Messages::PluginProxy::WindowedPluginVisibilityDidChange>(connection, decoder, this, &PluginProxy::windowedPluginVisibilityDidChange);
#endif
    if (decoder.messageName() == Messages::PluginProxy::SetPluginIsPlayingAudio::name())
        return IPC::handleMessage<Messages::PluginProxy::SetPluginIsPlayingAudio>(connection, decoder, this, &PluginProxy::setPluginIsPlayingAudio);
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
#if ENABLE(IPC_TESTING_API)
    if (connection.ignoreInvalidMessageForTesting())
        return;
#endif // ENABLE(IPC_TESTING_API)
    ASSERT_NOT_REACHED_WITH_MESSAGE("Unhandled message %s to %" PRIu64, IPC::description(decoder.messageName()), decoder.destinationID());
}

bool PluginProxy::didReceiveSyncPluginProxyMessage(IPC::Connection& connection, IPC::Decoder& decoder, UniqueRef<IPC::Encoder>& replyEncoder)
{
    Ref protectedThis { *this };
    if (decoder.messageName() == Messages::PluginProxy::ProxiesForURL::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::ProxiesForURL>(connection, decoder, replyEncoder, this, &PluginProxy::proxiesForURL);
    if (decoder.messageName() == Messages::PluginProxy::CookiesForURL::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::CookiesForURL>(connection, decoder, replyEncoder, this, &PluginProxy::cookiesForURL);
    if (decoder.messageName() == Messages::PluginProxy::GetAuthenticationInfo::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::GetAuthenticationInfo>(connection, decoder, replyEncoder, this, &PluginProxy::getAuthenticationInfo);
    if (decoder.messageName() == Messages::PluginProxy::GetPluginElementNPObject::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::GetPluginElementNPObject>(connection, decoder, replyEncoder, this, &PluginProxy::getPluginElementNPObject);
    if (decoder.messageName() == Messages::PluginProxy::Evaluate::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::Evaluate>(connection, decoder, replyEncoder, this, &PluginProxy::evaluate);
#if PLATFORM(X11)
    if (decoder.messageName() == Messages::PluginProxy::CreatePluginContainer::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::CreatePluginContainer>(connection, decoder, replyEncoder, this, &PluginProxy::createPluginContainer);
#endif
    if (decoder.messageName() == Messages::PluginProxy::DidCreatePlugin::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::DidCreatePlugin>(connection, decoder, replyEncoder, this, &PluginProxy::didCreatePlugin);
    if (decoder.messageName() == Messages::PluginProxy::DidFailToCreatePlugin::name())
        return IPC::handleMessageSynchronous<Messages::PluginProxy::DidFailToCreatePlugin>(connection, decoder, replyEncoder, this, &PluginProxy::didFailToCreatePlugin);
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    UNUSED_PARAM(replyEncoder);
#if ENABLE(IPC_TESTING_API)
    if (connection.ignoreInvalidMessageForTesting())
        return false;
#endif // ENABLE(IPC_TESTING_API)
    ASSERT_NOT_REACHED_WITH_MESSAGE("Unhandled synchronous message %s to %" PRIu64, description(decoder.messageName()), decoder.destinationID());
    return false;
}

} // namespace WebKit

#if ENABLE(IPC_TESTING_API)

namespace IPC {

template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_LoadURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::LoadURL::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_Update>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::Update::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_ProxiesForURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::ProxiesForURL::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_ProxiesForURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::ProxiesForURL::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_CookiesForURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CookiesForURL::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_CookiesForURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CookiesForURL::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_SetCookiesForURL>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::SetCookiesForURL::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_GetAuthenticationInfo>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::GetAuthenticationInfo::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_GetAuthenticationInfo>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::GetAuthenticationInfo::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_GetPluginElementNPObject>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::GetPluginElementNPObject::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_GetPluginElementNPObject>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::GetPluginElementNPObject::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_Evaluate>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::Evaluate::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_Evaluate>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::Evaluate::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_CancelStreamLoad>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CancelStreamLoad::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_ContinueStreamLoad>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::ContinueStreamLoad::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_CancelManualStreamLoad>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CancelManualStreamLoad::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_SetStatusbarText>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::SetStatusbarText::Arguments>(globalObject, decoder);
}
#if PLATFORM(COCOA)
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_PluginFocusOrWindowFocusChanged>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::PluginFocusOrWindowFocusChanged::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_SetComplexTextInputState>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::SetComplexTextInputState::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_SetLayerHostingContextID>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::SetLayerHostingContextID::Arguments>(globalObject, decoder);
}
#endif
#if PLATFORM(X11)
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_CreatePluginContainer>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CreatePluginContainer::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_CreatePluginContainer>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::CreatePluginContainer::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_WindowedPluginGeometryDidChange>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::WindowedPluginGeometryDidChange::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_WindowedPluginVisibilityDidChange>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::WindowedPluginVisibilityDidChange::Arguments>(globalObject, decoder);
}
#endif
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_DidCreatePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::DidCreatePlugin::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_DidCreatePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::DidCreatePlugin::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_DidFailToCreatePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::DidFailToCreatePlugin::Arguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessageReply<MessageName::PluginProxy_DidFailToCreatePlugin>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::DidFailToCreatePlugin::ReplyArguments>(globalObject, decoder);
}
template<> std::optional<JSC::JSValue> jsValueForDecodedMessage<MessageName::PluginProxy_SetPluginIsPlayingAudio>(JSC::JSGlobalObject* globalObject, Decoder& decoder)
{
    return jsValueForDecodedArguments<Messages::PluginProxy::SetPluginIsPlayingAudio::Arguments>(globalObject, decoder);
}

}

#endif


#endif // ENABLE(NETSCAPE_PLUGIN_API)
